#! /usr/bin/env python
# -*- coding: utf-8 -*-

__version_info__ = ('0', '3', '0')
__version__ = '.'.join(__version_info__)
__author__ = 'R. Patrick Xian, others'

from . import dict_io, json_io, mat_io